@@ -276,7 +276,7 @@ checkKey mpt key =
            else (Just Red, Just "not a V4 key"))
         kv
     colorizePKA pka
-      | pka `elem` [RSA, EdDSA] = Colored (Just Green) Nothing pka
+      | pka `elem` [RSA, EdDSA, ECDH] = Colored (Just Green) Nothing pka
       | otherwise =
         Colored
           (Just Yellow)
@@ -284,8 +284,9 @@ checkKey mpt key =
           pka
     colorizePKS pka epks = uncurry Colored (colorizePKS' pka epks) (hush epks)
     colorizePKS' pka (Right pks)
-      | pka == EdDSA && pks >= 256 = (Just Green, Nothing)
-      | pka == EdDSA = (Just Yellow, Just "Public key size under 256 bits")
+      | pka `elem` [EdDSA, ECDH] && pks >= 256 = (Just Green, Nothing)
+      | pka `elem` [EdDSA, ECDH] =
+        (Just Yellow, Just "Public key size under 256 bits")
       | pka == RSA && pks >= 3072 = (Just Green, Nothing)
       | pka == RSA && pks >= 2048 =
         (Just Yellow, Just "Public key size between 2048 and 3072 bits")
